{ config, lib, pkgs, ... }:

{
  options.c3d2.audioServer = {
    enable = lib.mkEnableOption "Enable PulseAudio and Bluetooth sinks";
  };

  config = lib.mkIf config.c3d2.audioServer.enable {
    sound.enable = true;
    hardware.bluetooth = {
      enable = lib.mkDefault true;
      settings = {
        Policy.AutoEnable = true;
        General.DiscoverableTimeout = 0;
      };
    };

    hardware.pulseaudio = {
      enable = true;
      systemWide = true;
      tcp = {
        enable = true;
        anonymousClients.allowedIpRanges = [
          "127.0.0.0/8"
          "::1/128"
          "fd23:42:c3d2:500::/56"
          "172.22.99.0/24"
          "172.20.72.0/21"
          "2a00:8180:2c00:200::/56"
          "2a0f:5382:acab:1400::/56"
        ];
      };
      zeroconf.publish.enable = true;
      package = (pkgs.pulseaudio.override {
        bluetoothSupport = true;
        advancedBluetoothCodecs = true;
        zeroconfSupport = true;
      }).overrideAttrs (oldAttrs: {
        # one test times out
        doCheck = false;
      });
    };

    # pipewire has no systemwide pipewire-pulse
    # services.pipewire = {
    #   enable = true;
    #   config.pipewire-pulse = lib.importJSON ./pipewire-pulse.conf.json;
    #   pulse.enable = true;
    #   socketActivation = false;
    #   systemWide = true;
    # };

    security.rtkit.enable = true;

    # tell Avahi to publish CUPS and PulseAudio
    services.avahi = {
      enable = true;
      publish = {
        enable = true;
        addresses = true;
        userServices = true;
      };
    };

    systemd.services.bluetooth-agent = lib.mkIf config.hardware.bluetooth.enable {
      description = "Allow anyone to pair via Bluetooth";
      wantedBy = [ "multi-user.target" ];
      requires = [ "bluetooth.target" ];
      after = [ "bluetooth.service" ];
      serviceConfig = {
        Type = "simple";
        ExecStart = "${pkgs.bluez-tools}/bin/bt-agent -c NoInputNoOutput";
        Restart = "on-failure";
        RestartSec = 60;
      };
    };

    users = {
      groups = {
        pulse-access = { };
      };
      users.k-ot.extraGroups = [
        "pipewire"
        "pulse-access" # required for system wide pulseaudio
      ];
    };
  };
}
